@@ -62,6 +62,20 @@ class DaYun:
             offset += size
         return LunarUtil.JIA_ZI[offset]
 
+    def getXun(self):
+        """
+        获取所在旬
+        :return: 旬
+        """
+        return LunarUtil.getXun(self.getGanZhi())
+
+    def getXunKong(self):
+        """
+        获取旬空(空亡)
+        :return: 旬空(空亡)
+        """
+        return LunarUtil.getXunKong(self.getGanZhi())
+
     def getLiuNian(self):
 
         """
